@@ -20,14 +20,27 @@ class Shipment(BaseModel):
     ScheduledDeliveryDate: Optional[str]
     Package: Package
     
+    @staticmethod
+    def delivered_date_to_str(date: datetime, description: str):
+        
+        pass
+    
+    @property
+    def delivered_date(self) -> Optional[datetime]:
+        last_activity = self.Package.AllActivity[0]
+        if self.Package.is_delivered:
+            return last_activity.get_date
+        return None
+    
     @property
     def scheduled_delivery_date(self):
         date = None
-        if self.Package.RescheduledDeliveryDate is not None:
+        if self.Package.RescheduledDeliveryDate is not None :
             date = datetime.strptime(self.Package.RescheduledDeliveryDate, "%Y%m%d")
-            
         elif self.ScheduledDeliveryDate is not None:
             date = datetime.strptime(self.ScheduledDeliveryDate, "%Y%m%d")
-            
         return date
+    
+    
+    
         
\ No newline at end of file
